from distutils.core import setup

setup(
    name='pydobot',
    packages=['pydobot'],  # this must be the same as the name above
    version='0.1',
    description='Python 3 library for Dobot Magician',
    author='Luis Mesas',
    author_email='luismesas@gmail.com',
    url='https://github.com/luismesas/pydobot',  # use the URL to the github repo
    download_url='https://github.com/luismesas/pydobot/archive/0.1.tar.gz',  # I'll explain this in a second
    keywords=['dobot', 'magician', 'robotics'],  # arbitrary keywords
    classifiers=[],
)
